# Test file for Checking if the Builder meta-method works
require 'OS/Builder'
require 'Core/Locale'

# Describe test cases
describe PackerFiles::Builder do

  # Check if the builder's instance eval functionality
  # Works
  it 'checks builder instance_eval #1' do
     class TestBuilder < PackerFiles::Builder
        type_accessor PackerFiles::Core::Locale
     end
     builder = TestBuilder.new
     builder.Locale do |b|
       b.default  = 'en_IN'
     end
     builder.Locale.normalize
     builder.Locale.default.should eql('en_IN.UTF-8')
  end

  # Check normalize functionalty
  it 'checks normalization #5' do
     class TestBuilder < PackerFiles::Builder
        type_accessor PackerFiles::Core::Locale
     end
     builder = TestBuilder.new
     builder.Locale do |b|
       b.default   = 'en_IN'
       b.supported = ['en_IN']
     end
     builder.Locale.normalize
     builder.Locale.default.should eql('en_IN.UTF-8')
     builder.Locale.supported.first.should eql('en_IN.UTF-8')
  end

  # Check Hypervisor functionalty
  it 'checks Hypervisor #1' do
     class TestBuilder < PackerFiles::Builder
     end
     builder = TestBuilder.new
     builder.Hypervisors do |h|
       h.VirtualBox do |v|
         v.cpu_count = 2
         v.use_efi   = false
       end
       h.VMWare do |v|
         v.cpu_count = 2
         v.use_efi   = false
       end
       h.KVM do |v|
         v.cpu_count = 2
         v.use_efi   = false
       end
     end
     builder.Hypervisors.VirtualBox.cpu_count.should eql(2)
     builder.Hypervisors.VirtualBox.use_efi.should   be(false)
     builder.Hypervisors.VMWare.cpu_count.should eql(2)
     builder.Hypervisors.VMWare.use_efi.should   be(false)
     builder.Hypervisors.KVM.cpu_count.should eql(2)
     builder.Hypervisors.KVM.use_efi.should   be(false)
  end

  # Check Versions functionality
  it 'checks Versions #1' do
     class TestBuilder < PackerFiles::Builder
     end
     TestBuilder.respond_to?(:versions).should be(true)
     TestBuilder.versions.empty?.should be(true)
  end

  # Check Versions functionality
  it 'checks Versions #2' do
     class TestBuilder < PackerFiles::Builder
        def self.versions
	   ['12.04']
        end
     end
     TestBuilder.respond_to?(:versions).should be(true)
     TestBuilder.versions.empty?.should be(false)
     TestBuilder.versions.first.should  eql('12.04')
  end

end
