# Test file for CDImage class
require 'Core/CDImage'

# Describe test cases
describe PackerFiles::Core::CDImage do

  # Check for error conditions
  it 'checks error #1' do
     cd = PackerFiles::Core::CDImage.new do |var|
     end
     begin
        cd.normalize
     rescue PackerFiles::Core::NilException => e
        e.message.should include('arch')
     end
  end

  it 'checks error #2' do
     cd = PackerFiles::Core::CDImage.new do |var|
	var.arch     = 'i386'
     end
     begin
        cd.normalize
     rescue PackerFiles::Core::NilException => e
        e.message.should include('release')
     end
  end

  it 'checks error #3' do
     cd = PackerFiles::Core::CDImage.new do |var|
	var.arch     = 'i386'
	var.release  = '6.0.9'
     end
     begin
        cd.normalize
     rescue PackerFiles::Core::NilException => e
        e.message.should include('iso_name_pattern')
     end
  end

  it 'checks error #4' do
     cd = PackerFiles::Core::CDImage.new do |var|
	var.arch             = 'i386'
	var.release          = '6.0.9'
	var.iso_name_pattern = 'debian-6.0.9-i386-kde-CD-1.iso'
     end
     begin
        cd.normalize
     rescue PackerFiles::Core::NilException => e
        e.message.should include('check_sum_pattern')
     end
  end

  it 'checks error #5' do
     cd = PackerFiles::Core::CDImage.new do |var|
	var.arch              = 'i386'
	var.release           = '6.0.9'
	var.iso_name_pattern  = 'debian-6.0.9-i386-kde-CD-1.iso'
	var.check_sum_pattern = 'MD5SUM'
     end
     begin
        cd.normalize
     rescue PackerFiles::Core::NilException => e
        e.message.should include('check_sum_type')
     end
  end

  it 'checks error #6' do
     cd = PackerFiles::Core::CDImage.new do |var|
	var.arch              = 'i386'
	var.release           = '6.0.9'
	var.iso_name_pattern  = 'debian-6.0.9-i386-kde-CD-1.iso'
	var.check_sum_pattern = 'MD5SUM'
	var.check_sum_type    = 'md5'
     end
     begin
        cd.normalize
     rescue PackerFiles::Core::NilException => e
        e.message.should include('index_urls')
     rescue PackerFiles::Core::EmptyArrayException => e
        e.message.should include('index_urls')
     end
  end

  it 'checks iso / checksum values #1' do
     cd = PackerFiles::Core::CDImage.new do |var|
	var.arch              = 'i386'
	var.release           = '6.0.9'
	var.iso_name_pattern  = 'debian-6.0.9-i386-kde-CD-1.iso'
	var.check_sum_pattern = 'MD5SUMS'
	var.check_sum_type    = 'md5'
        var.index_urls        = [
        'http://cdimage.debian.org/mirror/cdimage/archive/@release@/@arch@/iso-cd/'
        ]
     end
     cd.normalize
     cd.iso_url.should eql('http://cdimage.debian.org/mirror/cdimage/archive/6.0.9/i386/iso-cd/debian-6.0.9-i386-kde-CD-1.iso')
     cd.check_sum.should eql('b125597ef23366594eb18b82352e06f9') if cd.check_sum_type != 'none'
  end

  it 'checks iso / checksum values #2' do
     cd = PackerFiles::Core::CDImage.new do |var|
	var.arch              = 'i386'
	var.release           = '6.0.9'
	var.check_sum_type    = 'md5'
	var.iso_url           = 'http://cdimage.debian.org/mirror/cdimage/archive/6.0.9/i386/iso-cd/debian-6.0.9-i386-kde-CD-1.iso'
	var.check_sum         = 'b125597ef23366594eb18b82352e06f9'
     end
     cd.normalize
     cd.iso_url.should eql('http://cdimage.debian.org/mirror/cdimage/archive/6.0.9/i386/iso-cd/debian-6.0.9-i386-kde-CD-1.iso')
     cd.check_sum.should eql('b125597ef23366594eb18b82352e06f9')
  end

  it 'checks iso / checksum values #3' do
     class DebianCD < PackerFiles::Core::CDImageImpl
	def get_iso_name_pattern
	'debian-6.0.9-i386-kde-CD-1.iso'
	end
	def get_check_sum_pattern
	'MD5SUMS'
	end
	def index_urls
	['http://cdimage.debian.org/mirror/cdimage/archive/@release@/@arch@/iso-cd/']
	end
	def get_check_sum_type
	  'md5'
	end
     end
     cd = PackerFiles::Core::CDImage.new do |var|
	var.arch              = 'i386'
	var.release           = '6.0.9'
	var.impl	      = DebianCD.new
     end
     cd.normalize
     cd.iso_url.should eql('http://cdimage.debian.org/mirror/cdimage/archive/6.0.9/i386/iso-cd/debian-6.0.9-i386-kde-CD-1.iso')
     cd.check_sum.should eql('b125597ef23366594eb18b82352e06f9') if cd.check_sum_type != 'none'
  end

  it 'checks documentation #1' do
     cd = PackerFiles::Core::CDImage.new do |var|
	var.arch              = 'i386'
	var.release           = '6.0.9'
	var.iso_name_pattern  = 'debian-6.0.9-i386-kde-CD-1.iso'
	var.check_sum_pattern = 'MD5SUMS'
	var.check_sum_type    = 'md5'
        var.index_urls        = [
        'http://cdimage.debian.org/mirror/cdimage/archive/@release@/@arch@/iso-cd/'
        ]
     end
     cd.normalize

     File.exist?(cd.class.doc_file).should be(true)
     result = PackerFiles.evaluate_erb(cd.class.doc_file, Hash.new)
     result.should_not include('kde')
     result = PackerFiles.evaluate_erb(cd.class.doc_file, {'obj' => cd})
     result.should include('kde')
  end

end
