# Test file for Disk
require 'Core/Disk'
require 'Core/Partition'

# Describe test cases
describe PackerFiles::Core::Disk do

  # Check normalize functionalty
  it 'checks normalization #1' do
     disk = PackerFiles::Core::Disk.new
     disk.name   = 'sda'
     disk.size   = '2GiB'
     disk.normalize
     disk.size.should eql(2048)
  end

  it 'checks normalization #2' do
     disk = PackerFiles::Core::Disk.new
     disk.name  = 'sda'
     disk.size  =  '2MiB'
     disk.normalize
     disk.size.should eql(2)
  end

  it 'checks normalization #3' do
     disk = PackerFiles::Core::Disk.new
     disk.name   = 'sda'
     disk.size   = '2TiB'
     disk.normalize
     disk.size.should eql(2097152)
  end

  it 'checks normalization #4' do
     disk = PackerFiles::Core::Disk.new
     disk.name   = 'sda'
     disk.size   = '2GB'
     disk.normalize
     disk.size.should eql(1907)
  end

  it 'checks normalization #5' do
     disk = PackerFiles::Core::Disk.new
     disk.name   = 'sda'
     disk.size   = '100MB'
     disk.normalize
     disk.size.should eql(95)
  end

  it 'checks normalization #6' do
     disk = PackerFiles::Core::Disk.new
     disk.name   = 'sda'
     disk.size   = '1TB'
     disk.normalize
     disk.size.should eql(909486)
  end

  # Checks for disks and Partitions
  it 'checks normalization #7' do
     part = PackerFiles::Core::Partition.new
     part.name  = 'A'
     part.size  = '2MB'
     disk = PackerFiles::Core::Disk.new
     disk.name   = 'sda'
     disk.size   = '1MB'
     disk.partitions.push(part)
     begin 
       disk.normalize
     rescue PackerFiles::Core::SizeException => e
       disk.size.should eql(1)
     end
  end

  it 'checks normalization #8' do
     part = PackerFiles::Core::Partition.new
     part.name  = 'A'
     part.size  = '1MB'
     disk = PackerFiles::Core::Disk.new
     disk.name   = 'sda'
     disk.size   = '1MB'
     disk.partitions.push(part)
     disk.normalize
     disk.size.should eql(1)
  end

  it 'checks Partition evaluation #9' do
     disk = PackerFiles::Core::Disk.new
     disk.name  = 'sda'
     disk.size  = '1MB'
     disk.Partition do |p|
	p.name = 'A'
        p.size = '1MB'
     end
     disk.normalize
     disk.size.should eql(1)
  end

  it 'checks Partition evaluation #10' do
     disk = PackerFiles::Core::Disk.new
     disk.name   = 'sda'
     disk.size   = '1MB'
     disk.Partition do |p|
        p.size = '1MB'
     end
     disk.normalize
     disk.size.should eql(1)
     disk.partitions.first.size.should eql(1)
     disk.partitions.first.name.should eql(0)
  end

  it 'checks Partition evaluation #11' do
     disk = PackerFiles::Core::Disk.new
     disk.name  =  'sda'
     disk.size  =  '2MB'
     disk.Partition do |p|
        p.size = '1MB'
     end
     disk.Partition do |p|
        p.size = '1MB'
     end
     disk.normalize
     disk.size.should eql(2)
     disk.partitions.first.size.should eql(1)
     disk.partitions.first.name.should eql(0)
     disk.partitions.last.size.should eql(1)
     disk.partitions.last.name.should eql(1)
  end

  it 'checks VG evaluation #12' do
     disk = PackerFiles::Core::Disk.new
     disk.name  =  'sda'
     disk.size  =  '6GiB'
     disk.Partition do |p|
        p.size = '5GiB'
     end
     disk.Partition do |p|
        p.size = '1GiB'
     end
     disk.VolumeGroup do |v|
       v.name  = 'VG'
       v.disk_names  = [0, 1]
       v.LogicalVolume do |l|
         l.size = '2GiB'
       end
       v.LogicalVolume do |l|
        l.size = '4GiB'
       end
     end
     disk.normalize
     disk.vg.lvs.size.should eql(2)
     disk.vg.lvs.first.size.should eql(2048)
     disk.vg.lvs.first.vg_name.should eql('VG')
     disk.vg.lvs.last.size.should eql(4096)
     disk.vg.lvs.last.vg_name.should eql('VG')
  end

  it 'checks VG evaluation #13' do
     disk = PackerFiles::Core::Disk.new
     disk.name =  'sda'
     disk.size =  '10GiB'
     disk.VolumeGroup do |v|
       v.name  = 'VG'
       v.disk_names  = ['sda']
       v.LogicalVolume do |l|
         l.size =  '2GiB'
       end
       v.LogicalVolume do |l|
        l.size  = '4GiB'
       end
     end
     disk.normalize
     disk.vg.lvs.size.should eql(2)
     disk.vg.lvs.first.size.should eql(2048)
     disk.vg.lvs.first.vg_name.should eql('VG')
     disk.vg.lvs.last.size.should eql(4096)
     disk.vg.lvs.last.vg_name.should eql('VG')
  end

  it 'checks Disk documentation #1' do
     disk = PackerFiles::Core::Disk.new
     disk.name =  'sdcc'
     disk.size =  '10GiB'
     disk.normalize
     File.exist?(disk.class.doc_file).should be(true)
     result = PackerFiles.evaluate_erb(disk.class.doc_file, Hash.new)
     result.should_not include((10*1024).to_s)
     result = PackerFiles.evaluate_erb(disk.class.doc_file, {'obj' => disk})
     result.should include((10*1024).to_s)
     result.should include('sdcc')
  end

end
